@@ -134,12 +134,6 @@ class Gitee():
                 log.error(f"request url is {url}, parameters is {parameters},headers is {headers} failed, response status code is {response.status_code}")
                 break
 
-
-DEFAULT_MACROS = {
-    "python3_pkgversion": '3.9',
-    "lustre_name":"lustre"
-}
-
 class OpenEuler():
     def __init__(self):
         pass
@@ -189,6 +183,21 @@ class OpenEuler():
                 log.info(f"仓库 {repo_name}（{repo_url}）已找到目标版本分支 {branch}")
                 yield repo_name, repo_url
 
+    def get_core_src_list(self):
+        core_src_list=[]
+        try:
+            with open("openEuler_core_src.txt", "r",encoding="utf-8") as f:
+                for line in f.readlines():
+                    if not line.strip():
+                        continue
+                    line_segs = line.strip().split("|")
+                    if len(line_segs)>=3:
+                        core_src_list.append(line_segs[2].strip())
+        except Exception as e:
+            log.error(f"get core src list failed, error is {e}")
+        finally:
+            return core_src_list
+
     def get_rpm_name_from_full_name(self, rpm):
         rpm_clean = rpm.strip()
 
@@ -341,14 +350,16 @@ class OpenEuler():
 if __name__ == "__main__":
     # 初始化获取器
     oe = OpenEuler()
-    rpm=oe.get_rpm_name_from_full_name("texlive-footbib-doc-svn17115.2.0.7-3.oe2403sp2.noarch.rpm")
-    print(rpm)
-    rpm=oe.get_rpm_name_from_full_name("oeAware-manager-debuginfo-v2.1.1-3.oe2403sp2.x86_64.rpm")
-    print(rpm)
-    rpm=oe.get_rpm_name_from_full_name("texlive-fontware-20210325-10.oe2403sp2.x86_64.rpm")
-    print(rpm)
-    rpm=oe.get_rpm_name_from_full_name("nodejs-lodash-valuesin-3.10.1-1.oe2403sp2.noarch.rpm")
-    print(rpm)
+    rs=oe.get_core_src_list()
+    print(rs)
+    # rpm=oe.get_rpm_name_from_full_name("texlive-footbib-doc-svn17115.2.0.7-3.oe2403sp2.noarch.rpm")
+    # print(rpm)
+    # rpm=oe.get_rpm_name_from_full_name("oeAware-manager-debuginfo-v2.1.1-3.oe2403sp2.x86_64.rpm")
+    # print(rpm)
+    # rpm=oe.get_rpm_name_from_full_name("texlive-fontware-20210325-10.oe2403sp2.x86_64.rpm")
+    # print(rpm)
+    # rpm=oe.get_rpm_name_from_full_name("nodejs-lodash-valuesin-3.10.1-1.oe2403sp2.noarch.rpm")
+    # print(rpm)
     # rs=oe.get_openEuler_everything_rpm_list("24.03-LTS-SP2", "x86_64")
     # print(f"everything {len(rs)} pkgs")
     # rs=oe.get_openEuler_epol_rpm_list("24.03-LTS-SP2", "x86_64")
